@@ -16,13 +16,13 @@ has '+colors' => (
             [ 0xaa, 0xaa, 0xaa ],    # white
                                      # bright
             [ 0x55, 0x55, 0x55 ],    # black
-            [ 0xfe, 0x55, 0x55 ],    # red
-            [ 0x55, 0xfe, 0x55 ],    # green
-            [ 0xfe, 0xfe, 0x55 ],    # yellow
-            [ 0x55, 0x55, 0xfe ],    # blue
-            [ 0xfe, 0x55, 0xfe ],    # magenta
-            [ 0x55, 0xfe, 0xfe ],    # cyan
-            [ 0xfe, 0xfe, 0xfe ],    # white
+            [ 0xff, 0x55, 0x55 ],    # red
+            [ 0x55, 0xff, 0x55 ],    # green
+            [ 0xff, 0xff, 0x55 ],    # yellow
+            [ 0x55, 0x55, 0xff ],    # blue
+            [ 0xff, 0x55, 0xff ],    # magenta
+            [ 0x55, 0xff, 0xff ],    # cyan
+            [ 0xff, 0xff, 0xff ],    # white
         ];
     }
 );
@@ -45,7 +45,7 @@ Brian Cassidy E<lt>bricas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2008-2010 by Brian Cassidy
+Copyright 2008-2011 by Brian Cassidy
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself. 
